import unittest
from crap.package_management import PackageManagement

class TestPackageManagement(unittest.TestCase):
    def setUp(self):
        self.package_management = PackageManagement()

    def test_add_important_package(self):
        package = 'test-package'
        self.package_management.add_important_package(package)
        with open(self.package_management.filepath, 'r') as file:
            self.assertIn(package, file.read())

    def test_factory_reset_important_packages(self):
        package = 'test-package'
        self.package_management.add_important_package(package)
        self.package_management.factory_reset_important_packages()

        with open(self.package_management.filepath, 'r') as file:
            self.assertNotIn(package, file.read())

if __name__ == "__main__":
    unittest.main()


import pathlib
import shutil
from typing import List


class PackageManagement:
    def __init__(self, filename="important_packages.txt"):
        self.filename = filename
        self.filepath = pathlib.Path(__file__).parent / "data" / self.filename

    def add_important_package(self, package: str):
        """
        Add a package to the list of important packages.

        Args:
            package (str): The name of the package to add.
            filename (str, optional): The name of the file to store the list of important packages.
                Defaults to "important_packages.txt".
        """
        with open(self.filepath, "r+", encoding="utf-8") as file:
            existing_packages = {line.strip() for line in file}
            if package not in existing_packages:
                file.write(package + "\n")
                print(f"✅ Added '{package}' to important packages")
            else:
                print(f"'{package}' is already listed as an important package")

    def show_important_packages(self) -> List[str]:
        """
        Display the list of important packages.

        Args:
            filename (str): The name of the file containing the list of important packages.
                Default is "important_packages.txt".

        Returns:
            List[str]: The list of important packages.

        """
        with open(self.filepath, "r", encoding="utf-8") as file:
            important_packages = [line.strip() for line in file]
            print("📦 Important packages:")
            for package in important_packages:
                print(f" - {package}")

    def remove_important_package(self, package: str):
        """
        Removes a package from the list of important packages.

        Args:
            package (str): The name of the package to be removed.
            filename (str, optional): The name of the file containing the list of important packages.
                Defaults to "important_packages.txt".
        """
        with open(self.filepath, "r+", encoding="utf-8") as file:
            lines = file.readlines()
            file.seek(0)
            file.truncate(0)
            for line in lines:
                if line.strip() != package:
                    file.write(line)

            if package in (line.strip() for line in lines):
                print(f"❌ Removed '{package}' from important packages")
            else:
                print(f"'{package}' was not found in important packages")

    def flush_important_packages(self):
        """
        Flushes the important packages by removing the contents of the specified file.

        Args:
            filename (str, optional): The name of the file to flush. Defaults to "important_packages.txt".
        """
        with open(self.filepath, "w", encoding="utf-8"):
            pass
        print("All important packages have been removed.")

    def factory_reset_important_packages(self):
        """
        Reset the list of important packages to the default packages
        """
        DEFAULT_PACKAGES_FILE = "default_important_packages.txt"
        default_packages_path = (
            pathlib.Path(__file__).parent / "data" / DEFAULT_PACKAGES_FILE
        )

        try:
            shutil.copyfile(default_packages_path, self.filepath)
            print("🔄 Reset important packages to default")
        except FileNotFoundError:
            print(f"Default packages file '{DEFAULT_PACKAGES_FILE}' not found")



import unittest
from crap.subprocesses import run_subprocess, execute_command_without_output, get_installed_packages

class SubprocessesTests(unittest.TestCase):
    def test_run_subprocess(self):
        command = ["echo", "Hello, World!"]
        result = run_subprocess(command)
        self.assertEqual(result.stdout.strip(), "Hello, World!")

    def test_execute_command_without_output(self):
        command = ["echo", "Hello, World!"]
        result = execute_command_without_output(command)
        self.assertIsNone(result)

    def test_get_installed_packages(self):
        packages = get_installed_packages()
        self.assertIsInstance(packages, list)

if __name__ == "__main__":
    unittest.main()


import unittest
import ast
from crap.module_checker import ImportsVisitor

class TestImportsVisitor(unittest.TestCase):
    def setUp(self):
        self.visitor = ImportsVisitor()

    def test_visit_Import(self):
        node = ast.parse('import os')
        self.visitor.visit_Import(node.body[0])
        self.assertIn('os', self.visitor.imported_modules)

    def test_visit_ImportFrom(self):
        node = ast.parse('from os import path')
        self.visitor.visit_ImportFrom(node.body[0])
        self.assertIn('os', self.visitor.imported_modules)

if __name__ == "__main__":
    unittest.main()


import ast
import pathlib
from crap.module_checker import ImportsVisitor

class PythonFileAnalyzer:
    def __init__(self, file_path: pathlib.Path):
        self.file_path = file_path
        self.imported_modules = set()

    def analyze(self):
        """
        Analyzes the Python file and extracts the imported modules.
        """
        code = self.file_path.read_text()
        tree = ast.parse(code)
        visitor = ImportsVisitor()
        visitor.visit(tree)
        self.imported_modules = visitor.imported_modules


import sys
import os


class VirtualEnvChecker:
    def __init__(self):
        self.venv_indicators = {
            "linux": {"bin", "include", "lib", "pyvenv.cfg"},
            "win32": {"Scripts", "Include", "Lib", "pyvenv.cfg"}
        }

    def is_likely_venv(self, path):
        """
        Checks if the given path is likely to be a virtual environment.
        
        Args:
            path (str): The path to check.

        Returns:
            bool: True if the path is likely to be a virtual environment, False otherwise.
        """
        platform = sys.platform
        indicators = self.venv_indicators.get(platform, set())
        return all(os.path.exists(os.path.join(path, ind)) for ind in indicators)




import unittest
from pathlib import Path
from unittest.mock import patch
from crap.crap_manager import CrapManager

class TestCrapManager(unittest.TestCase):
    def setUp(self):
        self.crap_manager = CrapManager(".")

    @patch('crap.crap_manager.CrapManager._analyze_file')
    def test_process_path_file(self, mock_analyze_file):
        self.crap_manager.path_ = Path(__file__)
        self.crap_manager._process_path()
        mock_analyze_file.assert_called_once_with(Path(__file__))

    @patch('crap.crap_manager.CrapManager._analyze_directory')
    def test_process_path_directory(self, mock_analyze_directory):
        self.crap_manager.path_ = Path('.')
        self.crap_manager._process_path()
        mock_analyze_directory.assert_called_once()

    @patch('crap.crap_manager.get_installed_packages', return_value=['os', 'pathlib'])
    @patch('crap.crap_manager.PythonFileAnalyzer')
    def test_analyze_file(self, mock_analyzer, mock_get_installed_packages):
        mock_analyzer_instance = mock_analyzer.return_value
        mock_analyzer_instance.imported_modules = ['os']
        self.crap_manager.package_usage_counter.pack_counter.clear()
        self.crap_manager.package_usage_counter.pack_counter = {'os': 0}
        self.crap_manager._analyze_file(Path(__file__))
        self.assertEqual(self.crap_manager.package_usage_counter.pack_counter, {'os': 1})

    @patch('crap.crap_manager.CrapManager._analyze_file')
    def test_analyze_directory(self, mock_analyze_file):
        self.crap_manager.path_ = Path('.')
        self.crap_manager._analyze_directory()
        self.assertGreater(mock_analyze_file.call_count, 0)

    @patch('crap.crap_manager.CrapManager._get_important_packages', return_value=['os'])
    @patch('crap.crap_manager.PackageUsageCounter.get_unused_packages', return_value=['pathlib'])
    @patch('crap.crap_manager.uninstall_package')
    def test_cleanup_packages(self, mock_uninstall_package, mock_get_unused_packages, mock_get_important_packages):
        self.crap_manager.package_usage_counter.pack_counter = {'os': 1, 'pathlib': 0}
        self.crap_manager._cleanup_packages()
        mock_uninstall_package.assert_called_once_with('pathlib')

if __name__ == "__main__":
    unittest.main()


import unittest
from crap.package_usage_counter import PackageUsageCounter

class PackageUsageCounterTests(unittest.TestCase):
    def setUp(self):
        self.package_usage_counter = PackageUsageCounter()

    def test_increment_package_count(self):
        package = 'typer'
        self.package_usage_counter.increment_package_count(package)
        self.assertEqual(self.package_usage_counter.pack_counter[package], 1)

    def test_get_unused_packages(self):
        important_packages = ['important_package']
        unused_package = 'unused_package'
        self.package_usage_counter.pack_counter[unused_package] = 0
        unused_packages = self.package_usage_counter.get_unused_packages(important_packages)
        self.assertIn(unused_package, unused_packages)

if __name__ == "__main__":
    unittest.main()


import ast
from typing import Any, Tuple


class ImportsVisitor(ast.NodeVisitor):
    """
    AST visitor to check if a specific module or names are imported in the code.
    """

    __slots__: Tuple[str] = ("module_name", "imported", "names")

    def __init__(self) -> None:
        """
        Args:
            module_name (str): The name of the module to check for.
            imported (bool): Whether the module is imported or not.
            names (Set[str]): Names to check for in case of 'from import' (default is None).
        """
        self.imported_modules = set()

    def visit_Import(self, node: ast.Import) -> Any:
        """
        Visit an Import node.

        Check if the specified module is imported.

        Args:
            node (ast.Import): The Import node to visit.
        """
        for name in node.names:
            self.imported_modules.add(name.name)

    def visit_ImportFrom(self, node: ast.ImportFrom) -> Any:
        """
        Visit an ImportFrom node.

        Check if the specified module is imported using 'from import'.

        Args:
            node (ast.ImportFrom): The ImportFrom node to visit.
        """
        self.imported_modules.add(node.module)




import unittest
from pathlib import Path
from crap.file_analyzer import PythonFileAnalyzer

class PythonFileAnalyzerTests(unittest.TestCase):
    def test_analyze(self):
        test_file = Path("test_file.py")
        test_file.write_text("import os\nimport sys\nimport math")

        analyzer = PythonFileAnalyzer(test_file)

        analyzer.analyze()

        self.assertEqual(analyzer.imported_modules, {"os", "sys", "math"})

        test_file.unlink()

if __name__ == "__main__":
    unittest.main()


import setuptools

install_requires = []
with open("requirements.txt", "r", encoding="UTF-8") as f_stream:
    for pack in f_stream:
        install_requires.append(pack)


setuptools.setup(
    name="just-crap",
    version=open("VERSION").read().strip(),
    packages=setuptools.find_packages(include=["crap", "crap.*"]),
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Valdon Vitija",
    author_email="valdonvitijaa@gmail.com",
    license="MIT",
    install_requires=install_requires,
    entry_points={
        "console_scripts": [
            "crap=crap.cli:get_app",
        ],
    },
    package_data={"crap": ["data/*"]},
)



import unittest
import tempfile
import os
from crap.virtual_env_checker import VirtualEnvChecker

class TestVirtualEnvChecker(unittest.TestCase):
    def setUp(self):
        self.venv_checker = VirtualEnvChecker()

    def test_is_likely_venv_with_venv(self):
        with tempfile.TemporaryDirectory() as temp_dir:
            os.makedirs(os.path.join(temp_dir, 'bin'))
            os.makedirs(os.path.join(temp_dir, 'include'))
            os.makedirs(os.path.join(temp_dir, 'lib'))
            open(os.path.join(temp_dir, 'pyvenv.cfg'), 'a').close()
            self.assertTrue(self.venv_checker.is_likely_venv(temp_dir))

    def test_is_likely_venv_without_venv(self):
        with tempfile.TemporaryDirectory() as temp_dir:
            self.assertFalse(self.venv_checker.is_likely_venv(temp_dir))

if __name__ == "__main__":
    unittest.main()